CREATE TABLE paymentmethods (id INT PRIMARY KEY UNIQUE, title VARCHAR, cash INT);
CREATE TABLE barcodes (product_id INT, barcode VARCHAR UNIQUE);
CREATE TABLE changes (id INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE, time_start INT, time_end INT, cash_start DOUBLE DEFAULT (0), cash_end DOUBLE DEFAULT (0));
CREATE TABLE productcategories (id INT PRIMARY KEY UNIQUE, parent_id INT, title VARCHAR, color VARCHAR DEFAULT transparent, date_delete INT, date_update INT, icon VARCHAR DEFAULT '');
CREATE TABLE products (id INT PRIMARY KEY UNIQUE, code VARCHAR, ppr INT DEFAULT (1), fast INT DEFAULT (0), title VARCHAR, short_title VARCHAR, img TEXT, category_id INT, stock DOUBLE, price DOUBLE, buy_price DOUBLE DEFAULT(0), vat INT, vat_type INT, quantity DOUBLE DEFAULT (1), marking INT DEFAULT(0), marking_group VARCHAR DEFAULT '', egais INT DEFAULT(0), date_delete INT, date_update INT, print_group VARCHAR DEFAULT '');
CREATE TABLE receipts (id INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE, user_id INT, rm VARCHAR, store INT, table_id INTEGER DEFAULT (0), changes INT, changes_data TEXT, time DOUBLE, type INT, payment VARCHAR, sum DOUBLE, client VARCHAR, card VARCHAR, partner_id INT, create_receipt INT DEFAULT (0), description TEXT, lines_count INT, discount INT, remote INT DEFAULT(0));
CREATE TABLE receiptlines (id INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE, receipt_id INT, product_id INT, product_title VARCHAR, price DOUBLE, price0 DOUBLE, vat INT, vat_type INT, count DOUBLE, discount INT, line_discount INT, description TEXT, loyalty INT DEFAULT(0), mark TEXT DEFAULT '', kitchen INT(1) DEFAULT(0), bar INT(1) DEFAULT(0));
CREATE TABLE synchronization (id INTEGER PRIMARY KEY, time_start INT, time_update INT, tickets_update INT, users_update INT, partners_update INT, partners_timer INT, auto_sinch INT, method INT, loyalty INT, fiscalization INT);
INSERT INTO synchronization (id, time_start, time_update, tickets_update, users_update, partners_update, auto_sinch, method, loyalty, fiscalization, partners_timer) VALUES (1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
CREATE TABLE fr_settings (id INTEGER PRIMARY KEY, printer VARCHAR UNIQUE, header TEXT, footer TEXT, url VARCHAR, pays_type VARCHAR, vat_type VARCHAR, sno VARCHAR, active INT, type INT, driver VARCHAR, version VARCHAR, auto_incassation INT DEFAULT (0), line_by_line INT(1) DEFAULT(0));
INSERT INTO fr_settings (id, printer, header, footer, url, pays_type, vat_type, sno, active, type, driver, version, auto_incassation, line_by_line) VALUES (1, 'kkm', '', 'feed;3;', 'http://127.0.0.1:8888/req', '{"1":"0","2":"1"}', '["4","1","5","2","6","3"]', '01', '0', '1', '', '1.05', 0, 0), (2, 'pre', '', 'feed;3;', 'http://127.0.0.1:8888/req', '', '', '', '0', '', '', '', 0, 0), (3, 'kitchen', '', 'feed;3;', 'http://127.0.0.1:8888/req', '', '', '', '0', '', '', '', 0, 1), (4, 'bar', '', 'feed;3;', 'http://127.0.0.1:8888/req', '', '', '', '0', '', '', '', 0, 0);
CREATE TABLE usergroups (id INT PRIMARY KEY UNIQUE, title VARCHAR, module VARCHAR);
CREATE TABLE users (id INT PRIMARY KEY UNIQUE, name VARCHAR, short_name VARCHAR, group_id INT, pass VARCHAR, card VARCHAR, date_delete INT, hash VARCHAR);
CREATE TABLE settings (name VARCHAR UNIQUE, value TEXT);
INSERT INTO settings (name, value) VALUES ('auto_fullscreen', '1'), ('virtual_keyboard', '1'), ('cleaning', '0'), ('cafe_mode', '0'), ('auto_fiscalization', '0'), ('auto_replacekey', '0'), ('timezone', 'Europe/Moscow'), ('check_mark', '1'), ('check_mrc', '1'), ('egais', '0'), ('check_egais', '0'), ('url_egais', ''), ('auto_logout', '0'), ('descriptions_pattern', ''), ('card_code_pr', '29'), ('weight_code_pr', '28'), ('worker_code_pr', '27'), ('product_menu', '0');
CREATE TABLE logs (id INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE, txt TEXT, read INTEGER DEFAULT (0), time DOUBLE);
CREATE TABLE partners (card VARCHAR UNIQUE, partner_id INT, name VARCHAR, email VARCHAR, phone VARCHAR, discount INT, date_delete INT);
CREATE TABLE cd_settings (id INTEGER PRIMARY KEY, active INT, url VARCHAR, close_txt TEXT, seller_txt TEXT, driver VARCHAR);
INSERT INTO cd_settings (id, active, url, close_txt, seller_txt) VALUES (1, '0', 'http://127.0.0.1:8889/req', 'p;       Касса;      закрыта;', 'p;     Следующий;     покупатель;');
CREATE TABLE scales_settings (name VARCHAR UNIQUE, value VARCHAR);
INSERT INTO scales_settings (name, value) VALUES ('active', '0'), ('driver', ''), ('url', '');
CREATE TABLE rooms (id INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE, title VARCHAR UNIQUE, w INT DEFAULT (1), l INT DEFAULT (1));
CREATE TABLE tables (id INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE, room INTEGER, title VARCHAR, x INT, y INT);
CREATE TABLE loyalty (id INTEGER PRIMARY KEY, date_start INT, date_end INT, title VARCHAR, d1 TEXT, d2 TEXT, d3 TEXT, d4 TEXT, d5 TEXT, d6 TEXT, d7 TEXT, client INT, data TEXT);
CREATE TABLE discounts (value DOUBLE UNIQUE);
CREATE INDEX date_start ON loyalty (date_start);
CREATE INDEX date_end ON loyalty (date_end);
CREATE INDEX d1 ON loyalty (d1);
CREATE INDEX d2 ON loyalty (d2);
CREATE INDEX d3 ON loyalty (d3);
CREATE INDEX d4 ON loyalty (d4);
CREATE INDEX d5 ON loyalty (d5);
CREATE INDEX d6 ON loyalty (d6);
CREATE INDEX d7 ON loyalty (d7);
CREATE INDEX client ON loyalty (client);
CREATE INDEX data ON loyalty (data);
CREATE INDEX barcode ON barcodes (barcode);
CREATE INDEX product_id ON barcodes (product_id);
CREATE INDEX id_pay ON paymentmethods (id);
CREATE INDEX category_id ON products (category_id);
CREATE INDEX code ON products (code);
CREATE INDEX title ON products (title);
CREATE INDEX date_delete ON products (date_delete);
CREATE INDEX id_prod ON products (id);
CREATE INDEX marking ON products (marking);
CREATE INDEX egais ON products (egais);
CREATE INDEX date_delete_cat ON productcategories (date_delete);
CREATE INDEX parent_id ON productcategories (parent_id);
CREATE INDEX id ON productcategories (id);
CREATE INDEX date_delete_users ON users (date_delete);
CREATE INDEX card ON users (card);
CREATE INDEX id_users ON users (id);
CREATE INDEX id_usergroups ON usergroups (id);
CREATE INDEX line_product_id ON receiptlines (product_id);
CREATE INDEX line_receipt_id ON receiptlines (receipt_id);
CREATE INDEX receipt_id ON receipts (id);
CREATE INDEX receipt_type ON receipts (type);
CREATE INDEX receipt_time ON receipts (time);
CREATE INDEX change_id ON receipts (changes);
CREATE INDEX remote ON receipts (remote);
CREATE UNIQUE INDEX coordinates ON tables (room, x, y);
CREATE UNIQUE INDEX table_title ON tables (room, title);

